@@ -5,8 +5,8 @@ import 'vite/modulepreload-polyfill';  // recommended by django-vite, dunno why
 import { createApp } from 'vue';
 import { createPinia } from 'pinia';
 import { createRouter, createWebHistory } from "vue-router";
+import config from './config';
 import LoadPostList from "./components/LoadPostList.vue";
-import Counter from "./components/Counter.vue";
 import PostDetail from "./components/PostDetail.vue";
 
 import App from './App.vue';
@@ -22,20 +22,12 @@ const routes = [
         name: "PostDetail",
         component: PostDetail,
     },
-    {
-        path: "/counter",
-        name: "Counter",
-        component: Counter,
-    },
 ];
 
-let baseUrl = "/";
-const baseUrlElement = document.getElementById("base-url");
-if (baseUrlElement?.textContent) {
-    baseUrl = JSON.parse(baseUrlElement.textContent);
-}
+console.log("blog detail url: ", config.blogDetailUrl);
+console.log("vue route name: ", config.vueRouteName);
 const router = createRouter({
-    history: createWebHistory(baseUrl),
+    history: createWebHistory(config.blogUrl),
     routes,
   });
 
